@@ -5,19 +5,19 @@
 use std::{collections::HashMap, fmt::Display, fs, io::Write, path, str::FromStr};
 
 use anyhow::Context;
-use rust_embed::RustEmbed;
+use rust_embed::Embed;
 
 use crate::{
     manifest::Manifest,
     package_manager::PackageManager,
-    utils::{colors::*, lte},
+    utils::{self, colors::*, lte},
 };
 
 const CTA_MANIFEST_FILENAME: &str = ".manifest";
 
-#[derive(RustEmbed)]
+#[derive(Embed)]
 #[folder = "templates"]
-#[allow(clippy::upper_case_acronyms, non_camel_case_types)]
+#[allow(non_camel_case_types)]
 struct EMBEDDED_TEMPLATES;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
@@ -38,7 +38,9 @@ impl Display for Flavor {
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 #[non_exhaustive]
+#[derive(Default)]
 pub enum Template {
+    #[default]
     Vanilla,
     VanillaTs,
     Vue,
@@ -58,12 +60,6 @@ pub enum Template {
     Blazor,
 }
 
-impl Default for Template {
-    fn default() -> Self {
-        Template::Vanilla
-    }
-}
-
 impl Display for Template {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
@@ -256,8 +252,8 @@ impl<'a> Template {
         pkg_manager: PackageManager,
         project_name: &str,
         package_name: &str,
-        beta: bool,
-        mobile: bool,
+        identifier: &str,
+        rc: bool,
     ) -> anyhow::Result<()> {
         let manifest_bytes =
             EMBEDDED_TEMPLATES::get(&format!("template-{self}/{CTA_MANIFEST_FILENAME}"))
@@ -265,18 +261,19 @@ impl<'a> Template {
                 .data
                 .to_vec();
         let manifest_str = String::from_utf8(manifest_bytes)?;
-        let manifest = Manifest::parse(&manifest_str, mobile)?;
+        let manifest = Manifest::parse(&manifest_str, rc)?;
 
         let lib_name = format!("{}_lib", package_name.replace('-', "_"));
-        let project_name_pascal_case = Self::transform_to_pascal_case(project_name.to_string());
+        let project_name_pascal_case = utils::to_pascal_case(project_name);
 
-        let beta_str = beta.to_string();
+        let rc_str = rc.to_string();
         let manifest_template_data: HashMap<&str, &str> = [
-            ("beta", beta_str.as_str()),
+            ("rc", rc_str.as_str()),
             ("pkg_manager_run_command", pkg_manager.run_cmd()),
             ("lib_name", &lib_name),
             ("package_name", package_name),
             ("project_name", project_name),
+            ("identifier", identifier),
             ("project_name_pascal_case", &project_name_pascal_case),
             (
                 "double_dash_with_space",
@@ -297,15 +294,15 @@ impl<'a> Template {
         )?;
 
         let template_data: HashMap<&str, String> = [
-            ("stable", (!beta).to_string()),
-            ("beta", beta_str.clone()),
-            ("mobile", mobile.to_string()),
+            ("stable", (!rc).to_string()),
+            ("rc", rc_str.clone()),
             ("project_name", project_name.to_string()),
             (
                 "project_name_pascal_case",
                 project_name_pascal_case.to_string(),
             ),
             ("package_name", package_name.to_string()),
+            ("identifier", identifier.to_string()),
             (
                 "before_dev_command",
                 lte::render(
@@ -376,8 +373,8 @@ impl<'a> Template {
                 // conditional files:
                 // are files that start with a special syntax
                 //          "%(<list of flags separated by `-`>%)<file_name>"
-                // flags are supported package managers, stable, beta and mobile.
-                // example: "%(pnpm-npm-yarn-stable-beta)%package.json"
+                // flags are supported package managers, stable and rc.
+                // example: "%(pnpm-npm-yarn-stable-rc)%package.json"
                 name if name.starts_with("%(") && name[1..].contains(")%") => {
                     let mut s = name.strip_prefix("%(").unwrap().split(")%");
                     let (mut flags, name) = (
@@ -386,16 +383,12 @@ impl<'a> Template {
                     );
 
                     let for_stable = flags.contains(&"stable");
-                    let for_beta = flags.contains(&"beta");
-                    let for_mobile = flags.contains(&"mobile");
+                    let for_rc = flags.contains(&"rc");
 
                     // remove these flags to only keep package managers flags
-                    flags.retain(|e| !["stable", "beta", "mobile"].contains(e));
+                    flags.retain(|e| !["stable", "rc"].contains(e));
 
-                    if ((for_stable && !beta)
-                        || (for_beta && beta && !mobile)
-                        || (for_mobile && beta && mobile)
-                        || (!for_stable && !for_beta && !for_mobile))
+                    if ((for_stable && !rc) || (for_rc && rc) || (!for_stable && !for_rc))
                         && (flags.contains(&pkg_manager.to_string().as_str()) || flags.is_empty())
                     {
                         name
@@ -466,22 +459,4 @@ impl<'a> Template {
 
         Ok(())
     }
-
-    fn transform_to_pascal_case(s: String) -> String {
-        let mut result = String::new();
-        let mut capitalize_next = false;
-        for (s, c) in s.chars().enumerate() {
-            if s == 0 {
-                result.push(c.to_ascii_uppercase());
-            } else if capitalize_next {
-                result.push(c.to_ascii_uppercase());
-                capitalize_next = false;
-            } else if ['_', '-'].contains(&c) {
-                capitalize_next = true;
-            } else {
-                result.push(c);
-            }
-        }
-        result
-    }
 }
